
import React, { useState, useEffect } from 'react';
import { Card, CardContent } from '@/components/ui/card';
import { useFloridaFormSubmission } from './useFloridaFormSubmission';
import { useFormValidation } from './FloridaFormValidation';
import FloridaEnhancedConsent from './FloridaEnhancedConsent';
import FloridaFormHeader from './form/FloridaFormHeader';
import FloridaFormFields from './form/FloridaFormFields';
import FloridaSubmitButton from './form/FloridaSubmitButton';
import FloridaFormStatus from './form/FloridaFormStatus';
import { trackFloridaAccidentEvents } from '@/utils/metaPixel';
import { trackClarityEvents } from '@/utils/microsoftClarity';

const FloridaAccidentForm = () => {
  const [formData, setFormData] = useState({
    firstName: '',
    lastName: '',
    phone: '',
    email: '',
    tcpaConsent: true
  });

  const [hasTrackedFormStart, setHasTrackedFormStart] = useState(false);

  const { submitForm, isSubmitting, isComplete, submissionError, errorMessage } = useFloridaFormSubmission();

  const validation = useFormValidation(formData);

  const handleInputChange = (e: React.ChangeEvent<HTMLInputElement | HTMLTextAreaElement>) => {
    const { name, value } = e.target;
    setFormData(prev => ({ ...prev, [name]: value }));
  };

  const handleConsentChange = (checked: boolean) => {
    setFormData(prev => ({ ...prev, tcpaConsent: checked }));
  };

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();
    
    // Track lead submission on both platforms
    trackFloridaAccidentEvents.leadSubmitted(formData);
    trackClarityEvents.formSubmitted('florida_accident_case_review', {
      client_name: `${formData.firstName} ${formData.lastName}`,
      has_description: false
    });
    
    await submitForm(formData);
  };

  const isFormValid = () => {
    return (
      validation.firstNameValidation.isValid &&
      validation.lastNameValidation.isValid &&
      validation.phoneValidation.isValid &&
      validation.emailValidation.isValid &&
      formData.tcpaConsent
    );
  };

  useEffect(() => {
    const trackFormStart = () => {
      if (!hasTrackedFormStart) {
        // Track form start on both platforms
        trackFloridaAccidentEvents.formStarted();
        trackClarityEvents.formStarted('florida_accident_case_review');
        setHasTrackedFormStart(true);
      }
    };

    // Track when user starts typing in any field
    const firstInteraction = formData.firstName || formData.lastName || formData.phone || formData.email;
    if (firstInteraction && !hasTrackedFormStart) {
      trackFormStart();
    }
  }, [formData, hasTrackedFormStart]);

  useEffect(() => {
    if (isComplete && !submissionError) {
      // Track successful completion on both platforms
      trackFloridaAccidentEvents.thankYouPage();
      trackClarityEvents.conversion('case_review_submitted', 750);
    }
  }, [isComplete, submissionError]);

  // Show status screens if form is complete
  if (isComplete) {
    return (
      <FloridaFormStatus 
        isComplete={isComplete}
        submissionError={submissionError}
        errorMessage={errorMessage}
      />
    );
  }

  return (
    <Card className="shadow-xl border-0">
      {/* Best Choice Award Badge */}
      <div className="text-center py-4 bg-white">
        <img 
          src="/lovable-uploads/c25870c3-0c54-4383-858f-f2b222552b1a.png" 
          alt="Best Choice Award - The Louis Law Firm" 
          className="mx-auto h-12 md:h-16 w-auto"
        />
      </div>
      
      <FloridaFormHeader />
      
      {/* Attorney Introduction */}
      <div className="bg-gradient-to-r from-blue-50 to-blue-100 px-6 md:px-8 py-4 border-b border-blue-200">
        <div className="flex items-center gap-4">
          <div className="flex-shrink-0">
            <img 
              src="/lovable-uploads/20d2d18b-bf42-4468-8b92-2e7da79eb1c4.png" 
              alt="Skinner Louis - Founding Attorney" 
              className="w-20 h-24 md:w-24 md:h-28 object-cover object-top rounded-lg border-2 border-white shadow-md"
            />
          </div>
          <div className="flex-1 min-w-0">
            <h3 className="text-lg md:text-xl font-bold text-blue-900 mb-1">Skinner Louis</h3>
            <p className="text-sm md:text-base text-blue-700 font-semibold mb-1">Founding Attorney</p>
            <p className="text-xs md:text-sm text-blue-600 leading-relaxed">
              Personally reviews every case to maximize your compensation
            </p>
          </div>
        </div>
      </div>
      
      <CardContent className="p-6 md:p-8">
        <form onSubmit={handleSubmit} className="space-y-5">
          <FloridaFormFields
            formData={formData}
            onInputChange={handleInputChange}
            onLocationSelect={() => {}} // No longer used but keeping for compatibility
            validation={validation}
          />

          {/* Enhanced TCPA Consent */}
          <FloridaEnhancedConsent 
            tcpaConsent={formData.tcpaConsent}
            onConsentChange={handleConsentChange}
          />

          <FloridaSubmitButton
            isSubmitting={isSubmitting}
            isFormValid={isFormValid()}
          />
        </form>
      </CardContent>
    </Card>
  );
};

export default FloridaAccidentForm;
